% this defines the charge of the nuclei in the molecule we are analysing
Z = [1; 1];
% this defines the atomic orbitals we are using for LCAO
orb = {{'1s', '2s', '2px', '2py'}; {'1s', '2s', '2px', '2py'}};

constants

% integration area: [-univlim, univlim]x[-univlim, univlim] 
universallimit = 50*a0;
plotlimit = 8*a0;
ATol = 1E-6;
RTol = 1E-6;

% we want to calculate the energy for different distances of the protons
d_list = linspace(0, 2*pi, 4);%a0*[0.5:0.25:2 2.1:0.1:3 3.25 3.5 4:1:8];

% functions giving the position of the atoms dependent on the parameter
xAtom_d = @(d) 2.4/2*a0*[-cos(d), cos(d)];%[-d/2, d/2];
yAtom_d = @(d) 2.4/2*a0*[-sin(d), sin(d)];%[0, 0];
zAtom_d = @(d) [0, 0];

% these arrays will hold the energies and LCAO coefficients for all d
E_list = [];
V_list = [];

for d = d_list
    fprintf('\ndistance: %f\n', d/a0)
    xAtom = xAtom_d(d);
    yAtom = yAtom_d(d);
    zAtom = zAtom_d(d);

    [H, S] = calcHamiltonian(orb, Z, xAtom, yAtom, zAtom, universallimit,ATol,RTol);
    fprintf('max error on diagonal of S: %f\n', max(abs(diag(S) - 1)))
    
    % find the lowest eigenvalue and it's eigenvector
    [V,D] = eig(S\H);
    [~,ind] = sort(real(diag(D)));
    Ds = D(ind,ind);
    Vs = V(:,ind);

    E_list(:, end+1) = diag(Ds); % save all energies
    V_list(:, end+1) = Vs(:, 1); % save only the coefficients of the lowest energy
end

% this term is the additional proton-proton energy
E_protons = k2./abs(d_list);
E_total = E_list + E_protons;

% find the distance with the lowest energy and set some variables with it
[E_min, min_index] = min(real(E_total(1, :)));
d_min = d_list(min_index);
V_min = V_list(:, min_index);
xAtom_min = xAtom_d(d_min);
yAtom_min = yAtom_d(d_min);
zAtom_min = zAtom_d(d_min);

% energy of the unbounded parts
E_inf = -0.5*Eh;

% figure 1 plots the energies over distance with the bonding energy
figure(1)
plot(d_list/a0, E_total/ec)
hold on
plot([0, max(d_list)]/a0, E_inf/ec*[1, 1], '--k')

plot([d_min/a0, d_min/a0], [E_min/ec, E_inf/ec], '-k')
text(d_min/a0, (E_min + E_inf)/2/ec, [' ', num2str((E_inf - E_min)/ec, 3), ' eV'])

hold off
title('H_2^+ bonding energy')
ylim([-17, 0])
xlabel('d / a_0  distance between protons')
ylabel('Energy / eV')
%legend('plus, bonding', 'minus, antibonding')


% figure 2 plots the energy values without the proton-proton term
figure(2)
plot(d_list/a0, E_list/ec)
hold on
plot(d_list/a0, E_protons/ec, '--k')
hold off
title('H_2^+ orbital energy')
xlabel('d / a_0')
ylabel('Energy / eV')
%legend('plus', 'minus')

% plot the density in the xy plane of the solution
plot_molecule(orb, Z, xAtom_min, yAtom_min, zAtom_min, V_min, plotlimit)

fprintf('\nLCAO coefficients:\n')
disp(V_min)
fprintf('dissociation energy: %f eV\n', (E_inf - E_min)/ec)

save('results.mat', 'orb', 'Z', 'universallimit', 'd_list', 'E_list', 'E_protons', 'V_list', 'd_min', 'E_min', 'E_inf', 'V_min')
